@@ -2,7 +2,11 @@
 Core of The Project
 """
 from typing import Callable
-from sys import argv
+import sys
+
+from .ui import cprint, setup_colorama, red
+
+setup_colorama()
 
 
 def box_borders(func: Callable) -> Callable[[str], None]:
@@ -12,11 +16,11 @@ def box_borders(func: Callable) -> Callable[[str], None]:
 
     def wrapper(txt: str) -> None:
         txt_length = len(txt)
-        print(" " + "_" * (txt_length + 1))
-        print("/" + "_" * txt_length + "/|")
-        print("|" + " " * txt_length + "||")
+        cprint(" " + "_" * (txt_length + 1))
+        cprint("/" + "_" * txt_length + "/|")
+        cprint("|" + " " * txt_length + "||")
         func("|" + txt + "||")
-        print("|" + "_" * txt_length + "|/")
+        cprint("|" + "_" * txt_length + "|/")
 
     return wrapper
 
@@ -24,9 +28,9 @@ def box_borders(func: Callable) -> Callable[[str], None]:
 @box_borders
 def boxier(txt: str) -> None:
     """
-    Pass the text that you want to be printed with borders
+    Pass the text that you want to be cprinted with borders
     """
-    print(txt)
+    cprint(txt)
 
 
 def main() -> None:
@@ -34,8 +38,9 @@ def main() -> None:
     This is the main function
     """
     try:
-        message = argv[1]
+        message = sys.argv[1]
     except IndexError:
-        message = "You have to pass at least one word!"
+        cprint("You have to pass at least one word!", red)
+        sys.exit(0)
 
     boxier(message)
